@@ -70,6 +70,8 @@ def _tostr(text):
     :returns: text in str type
     :rtype: :obj:`str`
     """
+    if hasattr(text, "tostring"):
+        text = text.tostring()
     if isinstance(text, str):
         return text
     elif sys.version_info > (3,):
@@ -967,11 +969,10 @@ class PoolDSCreator(Creator):
                     storeDataSource(dsname, dsxml, server)
         else:
             for dsname, dsxml in self.datasources.items():
-                myfile = open("%s/%s%s.ds.xml" % (
-                    self.options.directory,
-                    self.options.file, dsname), "w")
-                myfile.write(dsxml)
-                myfile.close()
+                with open("%s/%s%s.ds.xml" % (
+                        self.options.directory,
+                        self.options.file, dsname), "w") as myfile:
+                    myfile.write(dsxml)
 
     def __createDevice(self, name, source, clientlike=True):
         """  create Device from name source and chtype
@@ -1129,11 +1130,10 @@ class OnlineDSCreator(Creator):
                     storeDataSource(dsname, dsxml, server)
         else:
             for dsname, dsxml in self.datasources.items():
-                myfile = open("%s/%s%s.ds.xml" % (
-                    self.options.directory,
-                    self.options.file, dsname), "w")
-                myfile.write(dsxml)
-                myfile.close()
+                with open("%s/%s%s.ds.xml" % (
+                        self.options.directory,
+                        self.options.file, dsname), "w") as myfile:
+                    myfile.write(dsxml)
 
     def createXMLs(self):
         """ creates datasource xmls of all online.xml simple devices
@@ -1287,9 +1287,6 @@ class CPCreator(Creator):
                     raise CPExistsException(
                         "Component '%s' already exists." % cpname)
         elif not self.options.overwrite:
-            print(self.options.overwrite)
-            print(self.options.file)
-            print(cpname)
             existing = self._componentFilesExist(
                 [cpname], self.options.file, self.options.directory)
             if existing:
@@ -1297,6 +1294,9 @@ class CPCreator(Creator):
                     "Component files '%s' already exist." % existing)
 
         self.createXMLs()
+        if not self.datasources and not self.components:
+            raise CPExistsException(
+                "Warning: Component %s cannot be created" % cpname)
         server = self.options.server
         if hasattr(self.options, "database") and \
            self.options.database:
@@ -1310,17 +1310,15 @@ class CPCreator(Creator):
                 storeComponent(cpname, cpxml, server, mand)
         else:
             for dsname, dsxml in self.datasources.items():
-                myfile = open("%s/%s%s.ds.xml" % (
-                    self.options.directory,
-                    self.options.file, dsname), "w")
-                myfile.write(dsxml)
-                myfile.close()
+                with open("%s/%s%s.ds.xml" % (
+                        self.options.directory,
+                        self.options.file, dsname), "w") as myfile:
+                    myfile.write(dsxml)
             for cpname, cpxml in self.components.items():
-                myfile = open("%s/%s%s.xml" % (
-                    self.options.directory,
-                    self.options.file, cpname), "w")
-                myfile.write(cpxml)
-                myfile.close()
+                with open("%s/%s%s.xml" % (
+                        self.options.directory,
+                        self.options.file, cpname), "w") as myfile:
+                    myfile.write(cpxml)
 
     @classmethod
     def _replaceName(cls, filename, cpname, module=None):
@@ -1436,8 +1434,8 @@ class CompareOnlineDS(object):
                 dv.sardanahostname = self._getChildText(
                     device, "sardanahostname")
                 if name not in dct.keys():
-                    dct[name] = []
-                dct[name].append(dv)
+                    dct[dv.sardananame or name] = []
+                dct[dv.sardananame or name].append(dv)
         return dct
 
     def compare(self):
@@ -1448,13 +1446,13 @@ class CompareOnlineDS(object):
         common = sorted(set(dct1.keys()) & set(dct2.keys()))
         d1md2 = sorted(set(dct1.keys()) - set(dct2.keys()))
         d2md1 = sorted(set(dct2.keys()) - set(dct1.keys()))
-        addd1 = dict((str(k), [(str(dv.sardananame)
-                                if dv.sardananame else dv.sardananame)
-                               for dv in dct1[k]])
+        addd1 = dict((str(k),
+                      [(str(dv.name) if dv.name else dv.name)
+                       for dv in dct1[k]])
                      for k in d1md2)
-        addd2 = dict((str(k), [(str(dv.sardananame)
-                                if dv.sardananame else dv.sardananame)
-                               for dv in dct2[k]])
+        addd2 = dict((str(k),
+                      [(str(dv.name) if dv.name else dv.name)
+                       for dv in dct2[k]])
                      for k in d2md1)
         diff = {}
         for name in common:
@@ -1476,15 +1474,13 @@ class CompareOnlineDS(object):
                 for i1, dv in enumerate(dct1[name]):
                     if l1[i1]:
                         addd1[str(name)].append(
-                            str(dv.sardananame)
-                            if dv.sardananame else dv.sardananame)
+                            (str(dv.name) if dv.name else dv.name))
             elif True not in l1 and True in l2:
                 addd2[str(name)] = []
                 for i2, dv in enumerate(dct2[name]):
                     if l2[i2]:
                         addd2[str(name)].append(
-                            str(dv.sardananame)
-                            if dv.sardananame else dv.sardananame)
+                            (str(dv.name) if dv.name else dv.name))
             if True in l1 or True in l2:
                 diff[str(name)] = []
                 for i1, dv1 in enumerate(dct1[name]):
@@ -1494,9 +1490,11 @@ class CompareOnlineDS(object):
 
         if self._printouts:
             import pprint
-            print("Additional devices in file1 {name: sardananame} :\n")
+            print("Additional devices in '%s' {alias: [name]} :\n"
+                  % self.args[0])
             pprint.pprint(addd1)
-            print("\nAdditional devices in file2 {name: sardananame} :\n")
+            print("\nAdditional devices in '%s' {alias: [name]} :\n"
+                  % self.args[1])
             pprint.pprint(addd2)
             print("\nDiffrences in the common part:\n")
             pprint.pprint(diff)
@@ -1578,36 +1576,69 @@ class OnlineCPCreator(CPCreator):
                         cpnames.add(dv.name)
         return cpnames
 
+    def listcomponenttypes(self):
+        """ provides a list of standard component types
+
+        :returns: list of standard component types
+        :rtype: :obj:`list` <:obj:`str`>
+        """
+        return list(sorted(self.xmlpackage.moduleTemplateFiles.keys()))
+
     def createXMLs(self):
         """ creates component xmls of all online.xml complex devices
         """
         self.datasources = {}
         self.components = {}
-        hw = etree.parse(self.args[0],
-                         parser=XMLParser(collect_ids=False)).getroot()
-        if hw.tag != 'hw':
-            hw = hw.find('hw')
+        if self.options.component and self.options.cptype and \
+           self.options.device:
+            hw = [None]
+        else:
+            hw = etree.parse(
+                self.args[0],
+                parser=XMLParser(collect_ids=False)).getroot()
+            if hw.tag != 'hw':
+                hw = hw.find('hw')
         cpname = self.options.component
         tangohost = getServerTangoHost(
             self.options.external or self.options.server)
         for device in hw:
-            if device.tag == 'device':
-                dvname = self._getChildText(device, "name")
-                sardananame = self._getChildText(device, "sardananame")
-                name = sardananame or dvname
+            if device is None or device.tag == 'device':
+                if device is None:
+                    name = cpname
+                else:
+                    dvname = self._getChildText(device, "name")
+                    sardananame = self._getChildText(
+                        device, "sardananame")
+                    name = sardananame or dvname
                 if self.options.lower:
                     name = name.lower()
                     cpname = cpname.lower()
                 if name == cpname:
                     dv = Device()
                     dv.name = name
-                    dv.dtype = self._getChildText(device, "type")
-                    dv.module = self._getChildText(device, "module")
-                    dv.tdevice = self._getChildText(device, "device")
-                    dv.hostname = self._getChildText(device, "hostname")
-                    dv.sardananame = self._getChildText(device, "sardananame")
-                    dv.sardanahostname = self._getChildText(
-                        device, "sardanahostname")
+                    dv.dtype = self.options.cptype or \
+                        self._getChildText(device, "type")
+                    dv.module = self.options.cptype or \
+                        self._getChildText(device, "module")
+                    dv.tdevice = self.options.device or \
+                        self._getChildText(device, "device")
+                    hostname = None
+                    if self.options.host:
+                        host = self.options.host
+                        port = self.options.port \
+                            if self.options.port else "10000"
+                        hostname = "%s:%s" % (host, port)
+                    if hostname is None and device is None:
+                        hostname = tangohost
+                    if hostname is not None:
+                        dv.hostname = hostname
+                    if hostname is None and device is not None:
+                        dv.hostname = self._getChildText(device, "hostname")
+                    if device is not None:
+                        dv.sardananame = \
+                            self._getChildText(device, "sardananame")
+                        dv.sardanahostname = self._getChildText(
+                            device, "sardanahostname")
 
                     dv.findDevice(tangohost)
                     try:
@@ -1618,7 +1649,10 @@ class OnlineCPCreator(CPCreator):
                                   "type not defined"
                                   % (dv.name, dv.module, dv.dtype))
                         continue
-                    module = self._getModuleName(dv)
+                    if self.options.cptype:
+                        module = self.options.cptype
+                    else:
+                        module = self._getModuleName(dv)
                     if module:
                         if module.lower() in \
                            self.xmlpackage.moduleMultiAttributes.keys():
@@ -1714,7 +1748,7 @@ class StandardCPCreator(CPCreator):
         :returns: list of standard component types
         :rtype: :obj:`list` <:obj:`str`>
         """
-        return list(self.xmlpackage.standardComponentVariables.keys())
+        return list(sorted(self.xmlpackage.standardComponentVariables.keys()))
 
     def listcomponentvariables(self):
         """ provides a list of standard component types
