@@ -29,11 +29,6 @@ from . import filewriter
 
 
 WRITERS = {}
-try:
-    from . import pniwriter
-    WRITERS["pni"] = pniwriter
-except Exception:
-    pass
 try:
     from . import h5pywriter
     WRITERS["h5py"] = h5pywriter
@@ -63,10 +58,6 @@ class General(Runner):
         """ creates parser
 
         """
-        self._parser.add_argument(
-            "--pni", action="store_true",
-            default=False, dest="pni",
-            help="use pni module as a nexus reader")
         self._parser.add_argument(
             "--h5py", action="store_true",
             default=False, dest="h5py",
@@ -94,15 +85,11 @@ class General(Runner):
             writer = "h5cpp"
         elif options.h5py:
             writer = "h5py"
-        elif options.pni:
-            writer = "pni"
         elif "h5cpp" in WRITERS.keys():
             writer = "h5cpp"
-        elif "h5py" in WRITERS.keys():
-            writer = "h5py"
         else:
-            writer = "pni"
-        if (options.pni and options.h5py and options.h5cpp) or \
+            writer = "h5py"
+        if (options.h5py and options.h5cpp) or \
            writer not in WRITERS.keys():
             sys.stderr.write("nxsfileinfo: Writer '%s' cannot be opened\n"
                              % writer)
@@ -130,7 +117,7 @@ class General(Runner):
         """ parse entry of nexus file
 
         :param entry: nexus entry node
-        :type entry: :class:`pni.io.nx.h5.nxgroup`
+        :type entry: :class:`filewriter.FTGroup`
         :param description: dict description list
         :type description: :obj:`list` <:obj:`dict` <:obj:`str`, `any` > >
         :return: (key, value) name pair of table headers
@@ -144,7 +131,7 @@ class General(Runner):
             at = entry.attributes["NX_class"]
         except Exception:
             pass
-        if at and at[...] == 'NXentry':
+        if at and filewriter.first(at.read()) == 'NXentry':
             # description.append(None)
             # value = filewriter.first(value)
             key = "Scan entry:"
@@ -152,14 +139,15 @@ class General(Runner):
             # description.append({key: "Scan entry:", value: entry.name})
             # description.append(None)
             try:
-                vl = filewriter.first(entry.open("title")[...])
+                vl = filewriter.first(entry.open("title").read())
                 description.append(
                     {key: "Title:", value: vl})
             except Exception:
                 sys.stderr.write("nxsfileinfo: title cannot be found\n")
                 sys.stderr.flush()
             try:
-                vl = filewriter.first(entry.open("experiment_identifier")[...])
+                vl = filewriter.first(
+                    entry.open("experiment_identifier").read())
                 description.append(
                     {key: "Experiment identifier:",
                      value: vl})
@@ -170,9 +158,9 @@ class General(Runner):
             for ins in entry:
                 if isinstance(ins, filewriter.FTGroup):
                     iat = ins.attributes["NX_class"]
-                    if iat and iat[...] == 'NXinstrument':
+                    if iat and filewriter.first(iat.read()) == 'NXinstrument':
                         try:
-                            vl = filewriter.first(ins.open("name")[...])
+                            vl = filewriter.first(ins.open("name").read())
                             description.append({
                                 key: "Instrument name:",
                                 value: vl})
@@ -183,7 +171,8 @@ class General(Runner):
                             sys.stderr.flush()
                         try:
                             vl = filewriter.first(
-                                ins.open("name").attributes["short_name"][...])
+                                ins.open("name").attributes[
+                                    "short_name"].read())
                             description.append({
                                 key: "Instrument short name:",
                                 value: vl
@@ -197,10 +186,11 @@ class General(Runner):
                         for sr in ins:
                             if isinstance(sr, filewriter.FTGroup):
                                 sat = sr.attributes["NX_class"]
-                                if sat and sat[...] == 'NXsource':
+                                if sat and filewriter.first(sat.read()) \
+                                   == 'NXsource':
                                     try:
                                         vl = filewriter.first(
-                                            sr.open("name")[...])
+                                            sr.open("name").read())
                                         description.append({
                                             key: "Source name:",
                                             value: vl})
@@ -212,7 +202,7 @@ class General(Runner):
                                     try:
                                         vl = filewriter.first(
                                             sr.open("name").attributes[
-                                                "short_name"][...])
+                                                "short_name"].read())
                                         description.append({
                                             key: "Source short name:",
                                             value: vl})
@@ -221,9 +211,9 @@ class General(Runner):
                                             "nxsfileinfo: source short name"
                                             " cannot be found\n")
                                         sys.stderr.flush()
-                    elif iat and iat[...] == 'NXsample':
+                    elif iat and filewriter.first(iat.read()) == 'NXsample':
                         try:
-                            vl = filewriter.first(ins.open("name")[...])
+                            vl = filewriter.first(ins.open("name").read())
                             description.append({
                                 key: "Sample name:",
                                 value: vl})
@@ -233,7 +223,7 @@ class General(Runner):
                             sys.stderr.flush()
                         try:
                             vl = filewriter.first(
-                                ins.open("chemical_formula")[...])
+                                ins.open("chemical_formula").read())
                             description.append({
                                 key: "Sample formula:",
                                 value: vl})
@@ -243,13 +233,13 @@ class General(Runner):
                                 " be found\n")
                             sys.stderr.flush()
             try:
-                vl = filewriter.first(entry.open("start_time")[...])
+                vl = filewriter.first(entry.open("start_time").read())
                 description.append({key: "Start time:", value: vl})
             except Exception:
                 sys.stderr.write("nxsfileinfo: start time cannot be found\n")
                 sys.stderr.flush()
             try:
-                vl = filewriter.first(entry.open("end_time")[...])
+                vl = filewriter.first(entry.open("end_time").read())
                 description.append({key: "End time:",
                                     value: vl})
             except Exception:
@@ -261,7 +251,7 @@ class General(Runner):
                 attr = pn.attributes
                 names = [att.name for att in attr]
                 if "scan_command" in names:
-                    scommand = filewriter.first(attr["scan_command"][...])
+                    scommand = filewriter.first(attr["scan_command"].read())
                     pname = "%s (%s)" % (pname, scommand)
                 description.append({key: "Program:", value: pname})
         return [key, value]
@@ -270,7 +260,7 @@ class General(Runner):
         """ show general informations
 
         :param root: nexus file root
-        :type root: class:`pni.io.nx.h5.nxroot`
+        :type root: class:`filewriter.FTGroup`
         """
 
         description = []
@@ -279,7 +269,7 @@ class General(Runner):
 
         names = [at.name for at in attr]
         fname = filewriter.first(
-            (attr["file_name"][...]
+            (attr["file_name"].read()
              if "file_name" in names else " ") or " ")
         title = "File name: '%s'" % fname
 
@@ -343,10 +333,6 @@ class Field(Runner):
             "-s", "--source", action="store_true",
             default=False, dest="source",
             help="show datasource parameters")
-        self._parser.add_argument(
-            "--pni", action="store_true",
-            default=False, dest="pni",
-            help="use pni module as a nexus reader")
         self._parser.add_argument(
             "--h5py", action="store_true",
             default=False, dest="h5py",
@@ -374,15 +360,11 @@ class Field(Runner):
             writer = "h5cpp"
         elif options.h5py:
             writer = "h5py"
-        elif options.pni:
-            writer = "pni"
         elif "h5cpp" in WRITERS.keys():
             writer = "h5cpp"
-        elif "h5py" in WRITERS.keys():
-            writer = "h5py"
         else:
-            writer = "pni"
-        if (options.pni and options.h5py) or writer not in WRITERS.keys():
+            writer = "h5py"
+        if (options.h5cpp and options.h5py) or writer not in WRITERS.keys():
             sys.stderr.write("nxsfileinfo: Writer '%s' cannot be opened\n"
                              % writer)
             sys.stderr.flush()
@@ -410,7 +392,7 @@ class Field(Runner):
         :param options: parser options
         :type options: :class:`argparse.Namespace`
         :param root: nexus file root
-        :type root: class:`pni.io.nx.h5.nxroot`
+        :type root: class:`filewriter.FTGroup`
         """
         #: (:obj:`list`< :obj:`str`>)   \
         #     parameters which have to exists to be shown
