@@ -775,7 +775,7 @@ standardComponentVariables = {
             'doc': "beamtime file prefix (string)"
         },
         'currentpostfix': {
-            'default': ".txt",
+            'default': ".json",
             'doc': "beamtime file postfix (string)"
         },
         'commissiondir': {
@@ -787,7 +787,7 @@ standardComponentVariables = {
             'doc': "commission file prefix (string)"
         },
         'commissionpostfix': {
-            'default': ".txt",
+            'default': ".json",
             'doc': "commission file postfix (string)"
         },
     },
@@ -1274,6 +1274,20 @@ standardComponentVariables = {
             'doc': "second optional detasource name MANDATORY (datasource)"
         }
     },
+    'detectorlive': {
+        'detectordata': {
+            'default': None,
+            'doc': "detector live data (datasource)"
+        },
+        'detname': {
+            'default': 'detector',
+            'doc': "list of devices (string)"
+        },
+        'datatype': {
+            'default': 'NX_UINT32',
+            'doc': "list of devices (string)"
+        },
+    },
 }
 
 #: (:obj:`dict` <:obj:`str` , :obj:`list` <:obj:`str`> >)
@@ -1369,6 +1383,9 @@ standardComponentTemplateFiles = {
     'common3': [
         'common3_common.ds.xml',
     ],
+    'detectorlive': [
+        'detectorlive.xml',
+    ],
     'msnsar': [
         'msnsar_env.ds.xml',
         'sardanaenvironment.ds.xml',
@@ -1463,9 +1480,17 @@ moduleTemplateFiles = {
     'lambda': ['lambda.xml',
                'lambda_nxdata.ds.xml',
                'lambda_external_data.ds.xml'],
+    'lambdavds': ['lambdavds.xml',
+                  'lambdavds_nxdata.ds.xml',
+                  'lambdavds_triggermode_cb.ds.xml',
+                  'lambdavds_framenumbers_cb.ds.xml',
+                  'lambdavds_savefilename_cb.ds.xml'],
     'tangovimba': ['tangovimba.xml',
                    'tangovimba_nxdata.ds.xml',
                    'tangovimba_external_data.ds.xml'],
+    'dalsa': ['dalsa.xml',
+              'dalsa_nxdata.ds.xml',
+              'dalsa_external_data.ds.xml'],
     'lambda2m': ['lambda2m.xml',
                  'lambda2m_m1_nxdata.ds.xml',
                  'lambda2m_m2_nxdata.ds.xml',
@@ -1645,7 +1670,17 @@ moduleMultiAttributes = {
         'TotalLossFrames', 'CompressorShuffle', 'CompressionRate',
         'CompressionEnabled', 'Layout', 'ShutterTimeMax', 'ShutterTimeMin',
         'Width', 'Height', 'Depth', 'LiveFrameNo', 'DistortionCorrection',
-        'LiveLastImageData', 'FramesPerFile'
+        'LiveLastImageData', 'FramesPerFile', 'OpMode'
+    ],
+    'lambdavds': [
+        'TriggerMode', 'ShutterTime', 'DelayTime', 'FrameNumbers', 'ThreadNo',
+        'EnergyThreshold', 'OperatingMode', 'ConfigFilePath', 'SaveAllImages',
+        'FilePrefix', 'FileStartNum', 'FilePreExt', 'FilePostfix',
+        'SaveFilePath', 'SaveFileName', 'LatestImageNumber', 'LiveMode',
+        'TotalLossFrames', 'CompressorShuffle', 'CompressionRate',
+        'CompressionEnabled', 'Layout', 'ShutterTimeMax', 'ShutterTimeMin',
+        'Width', 'Height', 'Depth', 'LiveFrameNo', 'DistortionCorrection',
+        'LiveLastImageData', 'FramesPerFile', 'OpMode'
     ],
     'lambda2m': [
         'TriggerMode', 'ShutterTime', 'DelayTime', 'FrameNumbers', 'ThreadNo',
@@ -1655,7 +1690,7 @@ moduleMultiAttributes = {
         'TotalLossFrames', 'CompressorShuffle', 'CompressionRate',
         'CompressionEnabled', 'Layout', 'ShutterTimeMax', 'ShutterTimeMin',
         'Width', 'Height', 'Depth', 'LiveFrameNo', 'DistortionCorrection',
-        'LiveLastImageData'
+        'LiveLastImageData', 'OpMode'
     ],
     'pedetector': [
         'BinningMode', 'FileIndex', 'ExposureTime', 'SkippedAtStart',
@@ -1697,4 +1732,16 @@ moduleMultiAttributes = {
         'FileStartNum', 'FramesProcessed', 'Image16', 'Image8', 'ImageRaw',
         'MaxLoad', 'ReadMode', 'TuneMode', 'ViewingMode'
     ],
+    'dalsa': [
+        'FileDir', 'FilePostfix', 'FilePrefix', 'FileSaving', 'FileStartNum',
+        'TriggerMode', 'Width', 'Height', 'ExtendedExposure',
+        'BinComment',
+        'FramesProcessed', 'Image16', 'Image8', 'ImageRaw',
+        'FramesReceived', 'FrameRate', 'FramesPerNXFile', 'NXFileCompression',
+        'TurboMode', 'ImageEnc', 'ViewingMode',
+        'ThrashedBuffers', 'FramesToAcquire',
+        'AcquisitionFrameCount', 'AcquisitionMode', 'AcquisitionFrameMode',
+        'LinearityEqualizer', 'NrExposedFrames', 'NrOffsetFrames',
+        'Offset', 'PixelFormat', 'ReadOutMode', 'Standby', 'SumScheme'
+    ],
 }
